@@ -1,6 +1,6 @@
-#' Run Luminescence shiny apps
+#' @title Run Luminescence shiny apps
 #'
-#' A wrapper for [`runApp`] to start interactive shiny apps for the R package Luminescence.
+#' @description A wrapper for [shiny::runApp] to start interactive shiny apps for the R package Luminescence.
 #'
 #' The RLumShiny package provides a single function from which all shiny apps can be started: `app_RLum()`.
 #' It essentially only takes one argument, which is a unique keyword specifying which application to start.
@@ -9,32 +9,34 @@
 #'
 #' \tabular{lcl}{
 #' **Application name:** \tab  **Keyword:**  \tab **Function:** \cr
-#' Abanico Plot \tab *abanico* \tab [`plot_AbanicoPlot`] \cr
-#' Histogram \tab *histogram* \tab [`plot_Histogram`] \cr
-#' Kernel Density Estimate Plot \tab *KDE* \tab [`plot_KDE`] \cr
-#' Radial Plot \tab *radialplot* \tab [`plot_RadialPlot`] \cr
-#' Dose Recovery Test \tab *doserecovery* \tab [`plot_DRTResults`] \cr
-#' Cosmic Dose Rate \tab *cosmicdose*  \tab [`calc_CosmicDoseRate`] \cr
-#' CW Curve Transformation \tab *transformCW* \tab [`CW2pHMi`], [`CW2pLM`], [`CW2pLMi`], [`CW2pPMi`] \cr
-#' Filter Combinations \tab *filter* \tab [`plot_FilterCombinations`] \cr
-#' Fast Ratio \tab *fastratio* \tab [`calc_FastRatio`] \cr
-#' Fading Correction \tab *fading* \tab [`analyse_FadingMeasurement`], [`calc_FadingCorr`] \cr
-#' Test Stimulation Power \tab *teststimulationpower* \tab  [`plot_RLum`]
+#' Abanico Plot \tab *abanico* \tab [Luminescence::plot_AbanicoPlot] \cr
+#' Histogram \tab *histogram* \tab [Luminescence::plot_Histogram] \cr
+#' Kernel Density Estimate Plot \tab *KDE* \tab [Luminescence::plot_KDE] \cr
+#' Radial Plot \tab *radialplot* \tab [Luminescence::plot_RadialPlot] \cr
+#' Dose Recovery Test \tab *doserecovery* \tab [Luminescence::plot_DRTResults] \cr
+#' Cosmic Dose Rate \tab *cosmicdose*  \tab [Luminescence::calc_CosmicDoseRate] \cr
+#' CW Curve Transformation \tab *transformCW* \tab [Luminescence::convert_CW2pHMi], [Luminescence::convert_CW2pLM], [Luminescence::convert_CW2pLMi], [Luminescence::convert_CW2pPMi] \cr
+#' Filter Combinations \tab *filter* \tab [Luminescence::plot_FilterCombinations] \cr
+#' Fast Ratio \tab *fastratio* \tab [Luminescence::calc_FastRatio] \cr
+#' Fading Correction \tab *fading* \tab [Luminescence::analyse_FadingMeasurement], [Luminescence::calc_FadingCorr] \cr
+#' Test Stimulation Power \tab *teststimulationpower* \tab  [Luminescence::plot_RLum] \cr
+#' Scale Gamma Dose Rate \tab *scalegamma* \tab [Luminescence::scale_GammaDose] \cr
+#' RCarb app \tab *RCarb* \tab [RCarb::model_DoseRate]
 #' }
 #'
-#' The `app_RLum()` function is just a wrapper for [`runApp`].
-#' Via the `...` argument further arguments can be directly passed to [`runApp`].
+#' The `app_RLum()` function is just a wrapper for [shiny::runApp].
+#' Via the `...` argument further arguments can be directly passed to [shiny::runApp].
 #' See `?shiny::runApp` for further details on valid arguments.
 #'
 #'
-#' @param app [`character`] (**required**):
+#' @param app [character] (**required**):
 #' name of the application to start. See details for a list of available apps.
 #'
-#' @param ... further arguments to pass to [`runApp`]
+#' @param ... further arguments to pass to [shiny::runApp]
 #'
 #' @author Christoph Burow, University of Cologne (Germany)
 #'
-#' @seealso [`runApp`]
+#' @seealso [shiny::runApp]
 #'
 #' @examples
 #'
@@ -57,6 +59,8 @@
 #' app_RLum("fading")
 #' app_RLum("surfaceexposure")
 #' app_RLum("teststimulationpower")
+#' app_RLum("scalegamma")
+#' app_RLum("RCarb")
 #' }
 #'
 #' @md
@@ -74,7 +78,10 @@ app_RLum <- function(app = NULL, ...) {
                   "fastratio",
                   "fading",
                   "surfaceexposure",
-                  "teststimulationpower")
+                  "teststimulationpower",
+                  "scalegamma",
+                  "RCarb"
+                  )
 
   if (is.null(app)) {
 
